@@ -90,6 +90,22 @@ class ExceptionHandler:
         return decorate(f, wrapped)
 
 
+class ExtraMonitoringHandler:
+    @property
+    def extra_monitoring_request_fields(self) -> List[str]:
+        return []
+
+    def extract_fields_from_request(
+        self, request: Optional[SeldonMessage[RT]] = None
+    ) -> Dict[str, Any]:
+        if request is not None:
+            return {
+                label: getattr(request.jsonData, label)
+                for label in self.extra_monitoring_request_fields
+            }
+        return {}
+
+
 class BaseBentoService(BentoService, metaclass=abc.ABCMeta):
     def versioneer(self):
         return datetime.datetime.utcnow().strftime("%Y%m%d%H%M%I")
@@ -194,7 +210,10 @@ class BaseBentoServiceWithResponse(
 
 
 class BasePredictor(
-    BaseBentoServiceWithResponse[RE], Generic[RT, RE], metaclass=abc.ABCMeta
+    BaseBentoServiceWithResponse[RE],
+    Generic[RT, RE],
+    ExtraMonitoringHandler,
+    metaclass=abc.ABCMeta,
 ):
     @property
     @abc.abstractmethod
@@ -222,7 +241,9 @@ class BasePredictor(
         routing: Optional[int],
     ) -> None:
         if reward is not None:
-            self._monitor.observe_reward(reward)
+            self._monitor.observe_reward(
+                reward, extra=self.extract_fields_from_request(request)
+            )
 
     @api(route="send-feedback", input=SeldonJsonInput(), batch=False)
     def send_feedback(
